.. icalendar_compatibility documentation master file, created by
   sphinx-quickstart on Mon Jan 13 14:57:43 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   api
   development

.. toctree::
   :titlesonly:

   changes
